# -*- encoding: utf-8 -*-

# Author: M. Sakano (Wise Babel Ltd)

require 'active_support/all'
require 'db_suit_rails/sql_skelton/utils'  # class SqlSkelton is defined.

# =class SqlSkelton::Fkey
#
# ==Summary
#
# Class for mapping a foreign key relation
#
# ==Description
#
# Three methods only.  To access it, via child or parent.
#
class SqlSkelton::Fkey

  # Method remove_sqlprefix() is defined.
  include Object.const_get(parent_name)::Utils  # parent_name defined in active_support/all

  # Access the child via
  #
  #     fkey.child[:tbl]  # => Child table name
  #     fkey.child[:col]  # => Child column name
  attr_reader :child

  # Access the parent via
  #
  #     fkey.parent[:tbl]  # => Parent table name
  #     fkey.parent[:col]  # => Parent column name
  attr_reader :parent

  # Set up the basic parameters.
  # 
  # @param tbl_child [String] Table referenced to
  # @param col_child [String] Column referenced to
  # @param tbl_parent [String] Table referenced from
  # @param col_parent [String] Column referenced from
  def initialize(tbl_child, col_child, tbl_parent, col_parent)
    tbl_child  = remove_sqlprefix(tbl_child)
    tbl_parent = remove_sqlprefix(tbl_parent)
    @child  = { :tbl => tbl_child,  :col => col_child }
    @parent = { :tbl => tbl_parent, :col => col_parent } 
    if !(@child[:tbl] && @child[:col] && @parent[:tbl] && @parent[:col])
      msg = sprintf('child(tbl|col) = (%s | %s)  parent(tbl|col) = (%s | %s)', @child[:tbl].inspect, @child[:col].inspect, @parent[:tbl].inspect, @parent[:col].inspect)
      raise DbSuitRailsFkeyError, 'None of the table/column should be nil.: '+msg
    end
  end

  # Equality implementation
  #
  def ==(obj)
    begin
      (@child == obj.child) && (@parent == obj.parent)
    rescue
      false
    end 
  end
end
