# -*- encoding: utf-8 -*-

# Author: M. Sakano (Wise Babel Ltd)

class SqlSkelton

  # =module SqlSkelton::SuffixId
  #
  # ==Summary
  #
  # Module to define the constant {SqlSkelton::SuffixId::SuffixId}
  # and other common functions.
  #
  module Utils
    # Suffix to append to an "id"-type column name (in "client"-DBs).
    SuffixId = '_cli'

    #######################################################
    private
    #######################################################

    # Returns a unique new table/column name.
    #
    # If the CANDIDATE is accepted, returns it.
    # Else it searches for CANDIDATE1, CANDIDATE2, ... etc.
    # Or, n1_CANDIDATE, n2_CANDIDATE1, ... etc, if useprefix option is true.
    #
    # This method yields a block, where a candidate name is given and true should be returned when accepted.
    #
    # @param name_root [String, NilClass] Candidate new column name. If unspecified, copied from oldcol
    # @param useprefix [Boolean] If true, add a prefix as opposed to suffix.
    # @yield [name_cand] Candidate name is passed to the block.  It should return true if the name is OK.
    # @yieldparam [name_cand, String] Candidate name
    # @yieldreturn [String, NilClass] Candidate name if found, else nil.
    # @return [String, NilClass] Unique new column name
    def unique_name_cand(name_root, useprefix: false)
      yield(name_root) && (return name_root) 
      (1..99999).each do |i|
        name_cand = (useprefix ? sprintf('n%d_%s', i, name_root) : sprintf('%s%d', name_root, i))
        yield(name_cand) && (return name_cand) 
      end
      nil
    end


    # Remove the 'public.' prefix for the table (for the internal use)
    #
    # @param tblname [String] Table name
    # @return [String]
    def remove_sqlprefix(tblname)
      return tblname if !defined?(tblname.gsub)
      tblname = tblname.sub(/^public\./, '')
    end
  end
end

